@@ -15,7 +15,7 @@ import argparse
 import pprint
 
 from jax import numpy as np
-import uproot3 as uproot
+import uproot
 
 from .tuples import write_array, read_array
 from .resampling import store_to_cache
