@@ -10,14 +10,28 @@
 ###############################################################################
 
 import pprint
+import sys
 
 from .resampling import get_samples
 
 def main() : 
 
-  samples = get_samples().keys()
-  for s in sorted(samples) : 
-    print(f"{s}")
+  samples = get_samples()
+
+  if len(sys.argv)<2 : 
+    print("List available PIDGen2 calibration samples. Usage: ")
+    print("  pidgen2.list_samples [dataset]")
+    print("Available datasets are: ")
+    for ds in sorted(samples.keys()) : 
+      print(f"  {ds}")
+
+  else : 
+    ds = sys.argv[1]
+    if ds not in samples.keys() : 
+      print(f"Dataset '{ds}' is not available.")
+    else : 
+      for s in samples[ds].keys() : 
+        print(f"  {s}")
 
 if __name__ == "__main__" : 
   main()
