@@ -437,7 +437,7 @@ def get_or_create_template(sample_name, dataset_name, variable_name,
 def get_or_create_mc_template(sim_version, sample_name, dataset_name, variable_name, 
                     variable, config, kernels = None, use_calib_cache = False, control_plots = False, 
                     interactive_plots = False, local_prefix = ".", global_prefix = None, 
-                    max_files = 0, verbose = False, cachedir = None) : 
+                    max_files = 0, verbose = False, cachedir = None, external_normaliser = None) : 
   """
 
   """
@@ -495,7 +495,8 @@ def get_or_create_mc_template(sim_version, sample_name, dataset_name, variable_n
 
     template = create_template_multipass(variable, config, kernels = kernels, use_calib_cache = use_calib_cache, 
                     control_plots = control_plots, interactive_plots = interactive_plots, 
-                    prefix = template_storage, max_files = max_files, verbose = verbose, cachedir = calib_cache_dirname, mc = True)
+                    prefix = template_storage, max_files = max_files, verbose = verbose, cachedir = calib_cache_dirname, mc = True, 
+                    external_normaliser = external_normaliser)
 
     if template_storage : 
       f = open(template_storage + "/config.json", "w")
@@ -508,7 +509,8 @@ def get_or_create_mc_template(sim_version, sample_name, dataset_name, variable_n
 
 
 def create_template(variable, config, kernels = None, use_calib_cache = False, control_plots = False, 
-                    interactive_plots = False, prefix = "", max_files = 0, verbose = False, cachedir = None) : 
+                    interactive_plots = False, prefix = "", max_files = 0, verbose = False, cachedir = None, 
+                    external_normaliser = None) : 
   """
   Create PID calibration template from the calibration sample (smoothed PDF). 
 
@@ -596,8 +598,12 @@ def create_template(variable, config, kernels = None, use_calib_cache = False, c
   else : 
     weights = weights1
 
-  print(f"Creating normaliser structure")
-  normaliser = de.create_normaliser_vector(data, ranges = ranges, bins = normalise_bins, weights = weights)
+  if external_normaliser is not None : 
+    print(f"Using external normaliser")
+    normaliser = external_normaliser
+  else : 
+    print(f"Creating normaliser structure")
+    normaliser = de.create_normaliser_vector(data, ranges = ranges, bins = normalise_bins, weights = weights)
 
   print(f"Starting to normalise data array")
   norm_data = []
@@ -733,7 +739,8 @@ def create_template(variable, config, kernels = None, use_calib_cache = False, c
   return counts.astype(np.float32), np.sqrt(counts2).astype(np.float32), edges, normaliser
 
 def create_template_multipass(variable, config, kernels = None, use_calib_cache = False, control_plots = False, 
-                    interactive_plots = False, prefix = "", max_files = 0, verbose = False, cachedir = None, mc = False) : 
+                    interactive_plots = False, prefix = "", max_files = 0, verbose = False, cachedir = None, mc = False, 
+                    external_normaliser = None) : 
   """
   Create PID calibration template from the calibration sample (smoothed PDF). 
 
@@ -841,8 +848,12 @@ def create_template_multipass(variable, config, kernels = None, use_calib_cache
 
   print(f"\nRead {len(sample)} calibration subsamples from remote storage.")
 
-  print(f"Creating normaliser structure")
-  normaliser = de.create_normaliser_from_histograms(histograms)
+  if external_normaliser is not None : 
+    print(f"Using external normaliser")
+    normaliser = external_normaliser
+  else : 
+    print(f"Creating normaliser structure")
+    normaliser = de.create_normaliser_from_histograms(histograms)
 
   print(f"Pass: filling resampling template")
 
