@@ -11,11 +11,13 @@
 
 from ..datasets import converted_run1_pidcalib_datasets_dstar_pi as ds_run1
 from ..datasets import legacy_run2_pidcalib_datasets as ds_run2
+from ..mc_datasets import dstar_run2sim09_datasets as mc_ds_run2sim09
+
 from itertools import product
 
 common_params = {
     "calib_cache_branches" : ["pt", "eta", "ntr", "sw"],          # Names of variable branches in ROOT tree of the cache file 
-    "data_ranges" : [ (2.4, 4.4), (2.0, 5.0), (0.7, 3.1) ],       # Ranges of each variable after transformation
+    "data_ranges" : [ (2.4, 4.4), (1.9, 5.0), (0.7, 3.1) ],       # Ranges of each variable after transformation
     "labels" : [r"PID", r"$p_T$", r"$\eta$", r"$N_{\rm tr}$"],    # Labels for plots
     "names" : ["pid", "pt", "eta", "ntr"],                        # Short names of each variable for plot file names
     "max_weights" : None, 
@@ -45,6 +47,14 @@ sample_run2 = {
       "probe_sWeight" 
     ], 
     "trees" : ['DSt_PiPTuple/DecayTree', 'DSt_PiMTuple/DecayTree'], 
+    "variables" : [
+                   "CombDLLK", "CombDLLmu", "CombDLLe", "CombDLLp", 
+                   "MC15TuneV1_ProbNNpi", "MC15TuneV1_ProbNNK", "MC15TuneV1_ProbNNp", 
+                   "MC15TuneV1_ProbNNe", "MC15TuneV1_ProbNNmu", 
+                   "MC15TuneV1_ProbNNpiNotK", "MC15TuneV1_ProbNNpiNotKp", 
+                   "MC15TuneV1_ProbNNKNotpi", "MC15TuneV1_ProbNNKNotpip", 
+                   "MC15TuneV1_ProbNNpNotK", "MC15TuneV1_ProbNNKNotpiK", 
+                  ], 
     **common_params, 
   } 
   for pol in ["MagUp", "MagDown"] for year in ["2015", "2016", "2017", "2018"]
@@ -60,9 +70,37 @@ sample_run1 = {
       "probe_sWeight" 
     ], 
     "trees" : ['DecayTree'], 
+    "variables" : [
+                   "CombDLLK", "CombDLLmu", "CombDLLe", "CombDLLp", 
+                   "MC12TuneV2_ProbNNpi", "MC12TuneV2_ProbNNK", "MC12TuneV2_ProbNNp", 
+                   "MC12TuneV3_ProbNNpi", "MC12TuneV3_ProbNNK", "MC12TuneV3_ProbNNp", 
+                   "MC12TuneV3_ProbNNe", "MC12TuneV3_ProbNNmu", 
+                   "MC12TuneV3_ProbNNpiNotK", "MC12TuneV3_ProbNNpiNotKp", 
+                   "MC12TuneV3_ProbNNKNotpi", "MC12TuneV3_ProbNNKNotpip", 
+                   "MC12TuneV3_ProbNNpNotK", "MC12TuneV3_ProbNNpNotpiK", 
+                  ], 
     **common_params, 
   } 
   for pol in ["MagUp", "MagDown"] for year in ["2011", "2012"]
 }
 
+mc_sample_run2 = {
+  f"Sim09_{pol}_{year}" : {
+    "sample" : mc_ds_run2sim09[f"{pol}_{year}"], 
+    "prefix" : "dpi", 
+    "branches" : [
+      "dpi_PT", 
+      "dpi_ETA", 
+      "nTracks",
+    ], 
+    "trees" : ["dstar/dstar"], 
+    "variables" : [
+                   "MC15TuneV1_ProbNNpi", "MC15TuneV1_ProbNNK", 
+                  ], 
+    **common_params, 
+  }
+  for pol in ["MagUp", "MagDown"] for year in ["2015", "2016", "2017", "2018"]
+}
+
 sample = {**sample_run1, **sample_run2}
+mc_sample = {**mc_sample_run2 }
