@@ -10,7 +10,8 @@
 ###############################################################################
 
 variable = {
-    "branch" : "probe_MC12TuneV3_ProbNNpi*(1.-probe_MC12TuneV3_ProbNNk)", 
+    "expression" : "probe_MC12TuneV3_ProbNNpi*(1.-probe_MC12TuneV3_ProbNNk)", 
+    "branches" : ["probe_MC12TuneV3_ProbNNk", "probe_MC12TuneV3_ProbNNpi"], 
     "data_range" : (0., 1.), 
     "transform_forward" : "1.-(1.-x**0.25)**0.5", 
     "transform_backward" : "(1.-(1.-x)**2)**4", 
