@@ -10,7 +10,8 @@
 ###############################################################################
 
 variable = {
-    "branch" : "probe_MC15TuneV1_ProbNNp*(1.-probe_MC15TuneV1_ProbNNk)*(1.-probe_MC15TuneV1_ProbNNpi)", 
+    "expression" : "probe_MC15TuneV1_ProbNNp*(1.-probe_MC15TuneV1_ProbNNk)*(1.-probe_MC15TuneV1_ProbNNpi)", 
+    "branches" : ["probe_MC15TuneV1_ProbNNk", "probe_MC15TuneV1_ProbNNpi", "probe_MC15TuneV1_ProbNNp"], 
     "data_range" : (0., 1.), 
     "transform_forward" : "1.-(1.-x**0.25)**0.5", 
     "transform_backward" : "(1.-(1.-x)**2)**4", 
